<?php
namespace SSMLP;

use Aws\Credentials\Credentials;
use Aws\S3\S3Client;

include_once 'app.php';

class Adminend extends App{
    
    public function init() {
        add_action('admin_menu', [$this, 'register_admin_menu']);
        add_action('admin_action_ssmlp_savesettings', [$this, 'savesettings']);
        add_action('admin_action_ssmlp_savecolour', [$this, 'savecolour']);
        add_action('admin_action_ssmlp_upload_audio', [$this, 'uploadaudio']);
        add_action('admin_enqueue_scripts', [$this, 'codemirror_enqueue_scripts']);
    }


    function codemirror_enqueue_scripts($hook) {
        $cm_settings['codeEditor'] = wp_enqueue_code_editor(array('type' => 'text/css'));
        wp_localize_script('jquery', 'cm_settings', $cm_settings);
        wp_enqueue_script('wp-theme-plugin-editor');
        wp_enqueue_style('wp-codemirror');
		 wp_enqueue_style('colour_picker1',plugin_dir_url( __FILE__ )."/assets/css/jquery.colorpicker.css");
		     wp_enqueue_style( 'wp-color-picker' );
    	wp_enqueue_script( 'ssmlp_scriptcolor', plugins_url( '/assets/js/wp-color-picker-alpha.min.js',  __FILE__ ), array( 'wp-color-picker' ), '1.0.0', true );

        wp_enqueue_script("ssmlp_script", plugin_dir_url( __FILE__ )."/assets/js/script.js", array( 'jquery' ), true);
        wp_localize_script('ssmlp_editor', 'ssmlp', Helper::getJsConfig());
        wp_localize_script('ssmlp_script', 'ssmlp', Helper::getJsConfig());
		wp_enqueue_script( 'jquery-ui',"https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.js", array( 'jquery' ), false, true );
		wp_enqueue_script( 'my_colour_picker', plugin_dir_url( __FILE__ )."/assets/js/jquery.colorpicker.js", array( 'jquery' ), false, true );
		
		//wp_enqueue_style( 'wp-color-picker' );
		//wp_enqueue_script( 'my-script-handle', plugin_dir_url( __FILE__ )."/assets/js/my-script.js", array( 'wp-color-picker' ), false, true );
		wp_enqueue_script( 'my-script-handle', plugin_dir_url( __FILE__ )."/assets/js/my-script.js", array( 'jquery' ), false, true );
    }
    
    function render_menupage(){
        include 'views/_menupage.php';
    }
    
    function  render_color(){
        include 'views/_color.php';
    }
    
    function render_settings(){
        include 'views/_settings.php';
    }
    
    function render_conversion_history(){
        include 'views/_conversion_history.php';
    }

    function render_homographs(){

        $action = isset($_GET['action']) ? trim($_GET['action']) : "";

        if($action=='wlt_edit') {
            $id = isset($_GET['id']) ? intval($_GET['id']) : "" ;

            include 'views/wlt-edit-fn.php';
        }

        else if($action=='wlt_delete') {
            $id = isset($_GET['id']) ? intval($_GET['id']) : "" ;

            include 'views/wlt-delete-fn.php';
        }

        else if($action=='add_new_homograph') {
            include 'views/add-new-word.php';
        }

        else {
            include 'views/_homograph_data.php';
        }
        
    }
    
    function render_user_stats(){
        include 'views/_user_stats.php';
    }

    function render_audios(){
        include 'views/_audios.php';
    }
    
    function render_test(){
        include 'views/test.php';
    }
    
    public function register_admin_menu(){
        add_menu_page(
            'SSML Processor',
            'SSML Processor',
            'manage_options',
            'ssmlp_menu',
            array($this, 'render_menupage')
        );
        
        add_submenu_page(
            'ssmlp_menu',
            'SSML Editor',
            'SSML Editor', 
            'manage_options', 
            'ssmlp_test', 
            array($this, 'render_test')
        );
        
        add_submenu_page(
            'ssmlp_menu',
            'User Stats',
            'User Stats', 
            'manage_options', 
            'ssmlp_user_stats', 
            array($this, 'render_user_stats')
        );
        
        add_submenu_page(
            'ssmlp_menu',
            'Conversion History',
            'Conversion History', 
            'manage_options', 
            'ssmlp_conversion_history', 
            array($this, 'render_conversion_history')
        );

        add_submenu_page(
            'ssmlp_menu',
            'Audio Database',
            'Audio Database', 
            'manage_options', 
            'homograph_data', 
            array($this, 'render_homographs')
        );

        add_submenu_page(
            'ssmlp_menu',
            'Settings',
            'Settings', 
            'manage_options', 
            'ssmlp_settings', 
            array($this, 'render_settings')
        );
		 
        add_submenu_page(
            'ssmlp_menu',
            'Theme Color Options',
            'Theme Color Options', 
            'manage_options', 
            'ssmlp_color', 
            array($this, 'render_color')
        );
        
        add_submenu_page(
            'ssmlp_menu',
            'Audios',
            'Audios', 
            'manage_options', 
            'ssmlp_audios', 
            array($this, 'render_audios')
        );

    }
    
    function savesettings() {
        $aws_accesskey = $_POST['aws_accesskey'];
        $aws_secretkey = $_POST['aws_secretkey'];
        $bucket = $_POST['bucket'];
        // $license_key = $_POST['license_key'];
        $samplerate = $_POST['samplerate'];
        $voice = $_POST['voice'];
        $video = $_POST['video'];
        $additional_css = $_POST['additional_css'];
        // $idKey = $secretKey = ""; // enable and save, for removing keys.
        add_option("ssmlp_aws_accesskey", $aws_accesskey);
        add_option("ssmlp_aws_secretkey", $aws_secretkey);        
        add_option("s3_bucket", $bucket);
        // add_option("license_key", $license_key);
        add_option("ssmlp_samplerate", $samplerate);
        add_option("ssmlp_voice", $voice);
        add_option("ssmlp_video", $video);
        add_option("ssmlp_additional_css", $additional_css);
        update_option("ssmlp_aws_accesskey", $aws_accesskey);
        update_option("ssmlp_aws_secretkey", $aws_secretkey);        
        update_option("s3_bucket", $bucket);
        update_option("license_key", $license_key);
        update_option("ssmlp_samplerate", $samplerate);
        update_option("ssmlp_voice", $voice);
        update_option("ssmlp_video", $video);
        update_option("ssmlp_additional_css", $additional_css);
     /*    try {
            Helper::validate_serial_key($license_key);   
        }catch (\Exception $e) {
            add_option("license_key", "");
            update_option("license_key", ""); ?>
            <script>
                <?php echo 'alert("'.$e->getMessage().'");'; ?> 
                <?php echo 'window.location.replace("'.admin_url( 'admin.php?page=ssmlp_settings').'")'; ?>
            </script>
            <?php
            exit();
        } */
        wp_redirect("admin.php?page=ssmlp_settings");
    }
function savecolour(){
        $theme_colour = $_POST['ssmlp_theme_colour'];
		 $theme_border_colour = $_POST['ssmlp_border_colour'];
		 $theme_icon_colour = $_POST['ssmlp_icon_colour'];
		 $theme_bg_colour = $_POST['ssmlp_bg_colour'];
        add_option("ssmlp_theme_colour",  $theme_colour);
        update_option("ssmlp_theme_colour", $theme_colour);
		
		add_option("ssmlp_border_colour",  $theme_border_colour);
        update_option("ssmlp_border_colour", $theme_border_colour);	

		add_option("ssmlp_icon_colour",  $theme_icon_colour);
        update_option("ssmlp_icon_colour", $theme_icon_colour);	

		add_option("ssmlp_bg_colour",  $theme_bg_colour);
        update_option("ssmlp_bg_colour", $theme_bg_colour);	
		
        wp_redirect("admin.php?page=ssmlp_color");
    }
    function uploadaudio() {
        $awsAccessKey = get_option("ssmlp_aws_accesskey");
        $awsSecretKey   = get_option("ssmlp_aws_secretkey");
        $bucket   = get_option("s3_bucket", 'ssml-processor-audios');
        $path_link = $_FILES['i_file']['tmp_name'];
        $filename = 'audios/'.$_FILES['i_file']['name'];

        $credentials  = new Credentials($awsAccessKey, $awsSecretKey);

        $client = new S3Client([
            'version' => 'latest',
            'credentials' => $credentials,
            'region' => 'us-east-2',
            'http'    => [
                'verify' => false
            ]
        ]);
        
        if($filename != null){
            // Send a PutObject request and get the result object.
            $result = $client->putObject([
                'Bucket' => $bucket,
                'Key' => $filename,
                'Body' => 'this is the body!',
                'SourceFile' => $path_link,
                'ACL' => 'public-read'
            ]);

            // Download the contents of the object.
            $result = $client->getObject([
                'Bucket' => $bucket,
                'Key' => $filename
            ]);

            global $wpdb;
            $wpdb->insert('wp_ssmlp_audios', array(
                'name' => $_FILES['i_file']['name'],
                'link' => $client->getObjectUrl($bucket,$filename),
                'format' => 'mp3',
            ));
            wp_redirect("admin.php?page=ssmlp_audios");
        }else{
            wp_redirect("admin.php?page=ssmlp_audios");
        }
    }

}