<?php if ( ! defined( 'ABSPATH' ) ) { die; } // Cannot access pages directly.

// Plugin Menu
add_action( 'admin_menu', 'd2l_wcp_plugin_menu' );
function d2l_wcp_plugin_menu() {
	add_submenu_page( 'options-general.php', __( "WP ColorPicker", "d2l-wp-colorpicker" ), __( "WP ColorPicker", "d2l-wp-colorpicker" ),
		'manage_options', 'd2l-wp-colorpicker', 'd2l_color_picker_settings' );
}

// Color Settings Form
function d2l_color_picker_settings() {	require "includes/d2l-cp-settings.php"; }

// Add "Settings" link to the Plugin
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'd2l_wp_color_picker_plugin_action_links' );
function d2l_wp_color_picker_plugin_action_links( $links ) {
	$iris_color_picker_enhancer_settings_link = sprintf( '<a href="%s">%s</a>', admin_url( 'options-general.php?page=d2l-wp-colorpicker' ), __( 'Settings' ) );
	array_unshift( $links, $iris_color_picker_enhancer_settings_link );
	return $links;
}

// Register Plugin Settings
add_action( 'admin_init', 'd2l_cp_plugin_settings' );
function d2l_cp_plugin_settings() {
	for ($cp=1; $cp<=18; $cp++){
		register_setting( 'd2l_cp_colors', 'd2l_color_palettes'.$cp );
	}
}
register_activation_hook( __DIR__.'/index.php', 'd2l_cp_plugin_hooks' );
//register_activation_hook( __FILE__, 'd2l_cp_plugin_hooks' );
function d2l_cp_plugin_hooks() {
	add_option( 'd2l_color_palettes1', '#ededed', '', 'yes' );
	add_option( 'd2l_color_palettes2', '#ecf0f1', '', 'yes' );
	add_option( 'd2l_color_palettes3', '#c8d6e5', '', 'yes' );
	add_option( 'd2l_color_palettes4', '#d7ceb2', '', 'yes' );
	add_option( 'd2l_color_palettes5', '#34495e', '', 'yes' );
	add_option( 'd2l_color_palettes6', '#22313f', '', 'yes' );
	add_option( 'd2l_color_palettes7', '#2ecc71', '', 'yes' );
	add_option( 'd2l_color_palettes8', '#48b56a', '', 'yes' );
	add_option( 'd2l_color_palettes9', '#4fbfa8', '', 'yes' );
	add_option( 'd2l_color_palettes10', '#1f8dd6', '', 'yes' );
	add_option( 'd2l_color_palettes11', '#2574a9', '', 'yes' );
	add_option( 'd2l_color_palettes12', '#0c2c84', '', 'yes' );
	add_option( 'd2l_color_palettes13', '#5f27cd', '', 'yes' );
	add_option( 'd2l_color_palettes14', '#fad232', '', 'yes' );
	add_option( 'd2l_color_palettes15', '#ff9f43', '', 'yes' );
	add_option( 'd2l_color_palettes16', '#ed6789', '', 'yes' );
	add_option( 'd2l_color_palettes17', '#ff6b6b', '', 'yes' );
	add_option( 'd2l_color_palettes18', '#ee5253', '', 'yes' );
}


// Color Palettes
add_action( 'admin_footer', 'd2l_set_color_pallettes_scripts' );
add_action( 'customize_controls_print_footer_scripts', 'd2l_set_color_pallettes_scripts' );
function d2l_set_color_pallettes_scripts() {
	for ($cp = 1; $cp<=18; $cp++){
		${'d2l_color_palettes'.$cp}  = get_option('d2l_color_palettes'.$cp);
	}
	if ( wp_script_is( 'wp-color-picker', 'enqueued' ) ) {
		?>
        <script type="text/javascript">
            jQuery(function($) {
			  if (typeof $.wp !== 'undefined' && typeof $.wp.wpColorPicker !== 'undefined') {
			    $.wp.wpColorPicker.prototype.options = {
					width: 255,
					hide: true,
					border: false,
					palettes: [<?php for ($cp = 1; $cp<=18; $cp++){ echo "'".${'d2l_color_palettes'.$cp}."', ";	}?>]
			    };
			  }
			});

        </script>
		<?php
	}
}

add_action( 'admin_enqueue_scripts', 'd2l_wp_colorpicker' );
function d2l_wp_colorpicker() {
	// enqueue style
	wp_enqueue_style( 'wp-color-picker' );
	wp_enqueue_style( 'd2l-wp-colorpicker', plugins_url( 'css/d2l-wp-colorpicker.css', __FILE__ ), array( 'wp-color-picker' ), '1.0.0', 'all' );

	$current_screen = get_current_screen();
	if($current_screen ->id ==='settings_page_d2l-wp-colorpicker'){
		// enqueue scripts
		wp_enqueue_script( 'wp-color-picker' );
		wp_enqueue_script( 'd2l-wp-colorpicker', plugins_url( 'js/d2l-wp-colorpicker.js', __FILE__ ), array('jquery', 'wp-color-picker' ), '1.0.0', false );
	}

}

add_action( 'admin_head', 'd2l_cp_admin_styling' );
function d2l_cp_admin_styling() {
	$current_screen = get_current_screen();
	if($current_screen ->id ==='settings_page_d2l-wp-colorpicker'){  ?>
	    <style type="text/css">.d2l-cp-left-content{float:left;width:75%;height:auto;margin-top:30px;}.d2l-cp-left-content .d2l-cp-settings-body{background-color:#FFF;overflow:hidden;padding:10px;}.d2l-cp-settings-body span.d2l-curr-color-palette{display:inline-block;width:90px;margin-left:8px;padding:4px 0;}.d2l-cp-sidebar{float:right;width:28%;height:auto;margin-top:30px;}.desc_title{margin:.6em 0 1em!important;}.iris-picker{position:absolute!important;}.d2l_default_color_palette{color:#7f8c8d;}</style>
		<?php
	}
}

add_action( 'admin_head', 'd2l_cp_color_settings' );
function d2l_cp_color_settings() {
	$current_screen = get_current_screen();
	if($current_screen ->id ==='settings_page_d2l-wp-colorpicker'){
		?>
	    <script>
	        jQuery(document).ready(function () {
	            jQuery('.d2l-cp-field').iris({  width: 150 });
	            jQuery(document).click(function (e) {
	                if (!jQuery(e.target).is(".d2l-cp-field, .iris-picker, .iris-picker-inner")) {
	                    jQuery('.d2l-cp-field').iris('hide');
	                }
	            });
	            jQuery('.d2l-cp-field').click(function (event) {
	                jQuery('.d2l-cp-field').iris('hide');
	                jQuery(this).iris('show');
	                return false;
	            });
	        });

	    </script>
		<?php
	}
}