<?php
namespace SSMLP;
include_once 'enum.php';
include_once 'helpers.php';

class Frontend extends App{

    public function init() {
        add_action('init', [$this, 'request']);
        add_action('wp_enqueue_scripts', [$this,'enqueue_scripts']);
        add_shortcode('ssml_processor_editor', [$this, 'render_shortcode_editor']);
        add_shortcode('ssml_processor_recent_history', [$this, 'render_shortcode_recent_history']);
        add_shortcode('ssml_processor_select_audios', [$this, 'render_shortcode_select_audios']);
        add_action( 'wp_head', [$this, 'additional_css'] );
    }

    function request() {
        $actionname = stristr($_SERVER['REQUEST_URI'], "/ssmlp/");
        if($actionname == false) return;
        $actionname = str_ireplace("?".$_SERVER['QUERY_STRING'], "", $actionname);
        $actionname = str_ireplace("/ssmlp/", "", $actionname);
        
        if(!is_callable(array($this, "action_$actionname")))
            \wp_die("Action is not available to call.");

        call_user_func(array($this, "action_$actionname"));
        exit();
    }
    
    function enqueue_scripts() {
        wp_enqueue_script("ssmlp_tinymce", plugin_dir_url( __FILE__ )."/assets/js/tinymce/tinymce.js", false, true);
        wp_enqueue_script("ssmlp_script", plugin_dir_url( __FILE__ )."/assets/js/script.js", array( 'jquery' ), true);
        wp_localize_script('ssmlp_script', 'ssmlp', Helper::getJsConfig());
        wp_enqueue_script("ssmlp_editor", plugin_dir_url( __FILE__ )."/assets/js/editor.js", array( 'jquery' ), true);
        wp_localize_script('ssmlp_editor', 'ssmlp', Helper::getJsConfig());
        wp_enqueue_style("ssmlp_fontawesome", "https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css");
        wp_enqueue_style("ssmlp_style", plugin_dir_url( __FILE__ )."/assets/css/style.css");
    }

    function action_process_ssml() {
        header('Content-Type: application/json');
        
        try {
            global $wpdb;
            $ssml = $_POST['ssml'];
            $samplerate = $_POST['samplerate'];
            $voice = $_POST['voice'];
            $startaudio = $_POST['startaudio'];
            $backgroundaudio = $_POST['backgroundaudio'];
            $endaudio = $_POST['endaudio'];
            $ipa_text = $_POST['ipatext'];
            $projectId = $_POST['projectId'];
            $fileText = $_POST['fileName'];

            if(isset($_POST['ipatext'])) {
                //to check if the audio exists in db
                $select_qry =  "SELECT `ipa_audio` FROM `wp_phoneme_ipa` WHERE ipa_value = '$ipa_text'";
                $audio_url_db = $wpdb->get_row($select_qry);
                if($audio_url_db && $audio_url_db->ipa_audio) {
                    $resp = $this->json(['url' => $audio_url_db->ipa_audio, 'type' => 'db']);
                }else{
                    $url = Helper::create_audio($ssml, $samplerate, $voice, $startaudio, $backgroundaudio, $endaudio,$projectId,$fileText);
                    $audio_url_api = $url[0];
                    $update_qry =  "UPDATE `wp_phoneme_ipa` SET ipa_audio = '$audio_url_api' WHERE ipa_value = '$ipa_text'";
                    $wpdb->get_results($update_qry);
                    $resp = $this->json(['url' => $audio_url_api, 'type' => 'api']);
                }
            }else{
                $url = Helper::create_audio($ssml, $samplerate, $voice, $startaudio, $backgroundaudio, $endaudio,$projectId,$fileText);
                $resp = $this->json(['url' => $url]);
            }
        }
        catch (\Exception $e) {
            $resp = $this->json([], 1, $e->getMessage());
        }
        echo json_encode($resp);
        exit();
    }
    
    function action_download () {
        $filepath = $_GET['filepath'];
        $filename = $_GET['filename'];

        header('Content-Type: audio/mp3');
        header('Content-Disposition: attachment; filename="'.$filename.'"');
        
        $path = wp_upload_dir();
        readfile($path['basedir'].$filepath);
    }
    
    function action_history_delete () {
        header('Content-Type: application/json');
        $id = $_POST['id'];
        Helper::history_delete($id);
    }

    function action_audio_delete () {
        header('Content-Type: application/json');
        $id = $_POST['id'];
        Helper::audio_delete($id);
    }

    function action_get_sbe() {
        header('Content-Type: application/json');
        $id = $_POST['id'];
        $audios = Helper::get_sbe($id);
        $resp = $this->json(['aud' => $audios]);
        echo json_encode($resp);
    }

    function action_recent_history () {
        include "views/_recent_history.php";
    }

    function render_shortcode_select_audios () {
        ob_start();
        include "views/_select_audios.php";
        return ob_get_clean();
    }
    
    function render_shortcode_editor($attr) {
        ob_start();
        include "views/_ssmleditor.php";

        $attr = shortcode_atts( array(
            'allowed_conversions' => '',
            'allowed_characters' => ''
        ), $attr );

        add_option("allowed_conversions", $attr['allowed_conversions']);
        update_option("allowed_conversions", $attr['allowed_conversions']);
        add_option("allowed_characters", $attr['allowed_characters']);
        update_option("allowed_characters", $attr['allowed_characters']);
        return ob_get_clean();
    }
    
    function render_shortcode_recent_history($attr) {
        ob_start();
        echo '<div id="recent_history_box" class="ssmlp" ></div>';
        return ob_get_clean();
    }

    function additional_css() {
        $style =  get_option("ssmlp_additional_css");
        echo '<style>'.$style.'</style>';
    }
}