<?php 
namespace SSMLP;

require 'awssdk/aws-autoloader.php';
use Aws\Exception\AwsException;
use Aws\Polly\PollyClient;
use Aws\Credentials\Credentials;
use Aws\Lambda\LambdaClient;

use Aws\S3\S3Client;

use function GuzzleHttp\json_decode;

class Helper {
    
    public static function getJsConfig() {
        return array(
            'pluginurl' => plugins_url()."/ssml-processor/",
            'actionurl' => get_site_url()."/ssmlp/",
            
        );
    }

    public static function unique_id(){
        usleep(1); // Because we are making id on the basis of microseconds so we need to delay a microsecond.
        $m = explode(".", microtime(true));
        $seconds = $m[0];
        $microseconds = isset($m[1])?$m[1]:0;
        $uid = $seconds.str_pad($microseconds,4,'0', STR_PAD_LEFT).rand(111,999).rand(1,9)."";
        return $uid;
    }
    
    public static function history_delete($id) {
        global $wpdb;
        $wpdb->get_results ("UPDATE `wp_ssmlp_history` SET deleted=1 WHERE `id` = $id ");
    }

    public static function audio_delete($id) {
        global $wpdb;
        $wpdb->get_results ("UPDATE `wp_ssmlp_audios` SET deleted=1 WHERE `id` = $id ");
    }

    public static function get_SBE($id) {
        global $wpdb;
        $results = $wpdb->get_results ("SELECT `start_aud`,`background_aud`,`end_aud` FROM wp_ssmlp_history WHERE `id` = $id ");
        $start = $results[0]->start_aud;
        $background = $results[0]->background_aud;
        $end = $results[0]->end_aud;
        $audios = [$start,$background,$end];
        return $audios;
    }

    public static function conversion_stats_front(){
        global $wpdb;
        $id = get_current_user_id();
        $month = date('m');
        $result = $wpdb->get_results ( "SELECT COUNT(*) AS 'count' FROM wp_ssmlp_history WHERE `user_id` = $id AND MONTH(date) = $month" );
        $allowed_conversions = get_option("allowed_conversions");
        $conversions_done = $result[0]->count;
        $count = intval($allowed_conversions) - intval($conversions_done);
        add_option('remaining_conversions',$count);
        update_option('remaining_conversions',$count);

        if ($count >= 0) {
            return $count;
        }else{
            $count = 0;
            return $count;
        }
    }
    
    public static function check_quota_available($id) {
        if(current_user_can('editor') || current_user_can('administrator'))
            return true;
        
        global $wpdb;
        $month = date('m');
        $result = $wpdb->get_results ("SELECT *,COUNT(*) AS 'count' FROM wp_ssmlp_history 
            WHERE `user_id` = $id AND MONTH(date) = $month");

        $count = $result[0]->count;
        $allowed_conversions = $GLOBALS['allowed_conversions']['allowed_conversions'];
        if($count <= $allowed_conversions) return true;
        else return false;
    }
    
   /*  public static function validate_serial_key($license_key){
        $api_params = array(
            'wc-api'=> 'validate_serial_key',
            'serial'=> $license_key,
            'sku'=> 'SSMLProcessor',
        );
        $response = wp_remote_get(add_query_arg($api_params, 'http://wpaipros.com/'), array('timeout' => 20, 'sslverify' => false));
        
        if(json_decode($response['body'])->success == 'false')
            throw new \Exception('Serial key is not valid. Please contact site administrator.');
    } */

    public static function create_audio($ssml, $samplerate, $voice, $startaudio, $backgroundaudio, $endaudio,$projectId,$fileText) {
        if(!is_user_logged_in()) {
            throw new \Exception("Please login to process ssml.");
        }
        
        global $wpdb;
        $user_id = get_current_user_id();
        $res = self::check_quota_available($user_id);
        $date = date('Y-m-d H:i:s');

        $ssml = wp_unslash($ssml);
        $ssml = str_replace("amazon-","amazon:",$ssml);
        $ssml = str_replace("xml-","xml:",$ssml);

        $awsAccessKey = get_option("ssmlp_aws_accesskey");
        $awsSecretKey   = get_option("ssmlp_aws_secretkey");
        
        $credentials  = new Credentials($awsAccessKey, $awsSecretKey);

        $client = new LambdaClient([
            'version' => 'latest',
            'credentials' => $credentials,
            'region' => 'us-east-2',
            'http'    => [
                'verify' => false
            ]
        ]);

        if($res) {
            $uploads = wp_upload_dir();
            $filename = "aud_".self::unique_id().".mp3";
            $savepath = $uploads['path']."/ssmlaudios/$filename";
            if(!is_dir($uploads['path']."/ssmlaudios/"))
                mkdir($uploads['path']."/ssmlaudios/");
            $url = $uploads['url']."/ssmlaudios/$filename";

            $result = $client->invoke(array(
                'FunctionName' => 'SSMLP_CreateAudio',
                'Payload' => json_encode([
                    "id_key" => $user_id,
                    "ssml" => "<speak>".$ssml."</speak>",
                    "samplerate" => $samplerate,
                    "voice" => $voice,
                    "startaudio" => $startaudio,
                    "backgroundaudio" => $backgroundaudio,
                    "endaudio" => $endaudio,
                ])
            ));
            $resp = $result['Payload']->getContents();
            $resp = json_decode($resp, true);
            
            if(isset($resp['error']) && $resp['error'] == 1) {
                throw new \Exception($resp['message']);
            }
            
            $url = $resp['url'];
            $textsize = $resp['textsize'];
            $filesize = $resp['filesize'];
            $samplerate = $resp['samplerate'];
            $bitrate = $resp['bitrate'];
            $count = Helper::conversion_stats_front();
            $wpdb->insert('wp_ssmlp_history', array(
                'text' => $ssml,
                'url' => $url,
                'date' => $date,
                'user_id' => $user_id,
                'deleted' => 0,
                'filesize' => $filesize,
                'textsize' => $textsize,
                'filename' => $filename,
                'filepath' => $savepath,
                'start_aud' => $startaudio,
                'background_aud' => $backgroundaudio,
                'end_aud' => $endaudio,
                'samplerate' => $samplerate,
                'bitrate' => $bitrate,
                'project_id' => $projectId,
                'file_name' => $fileText
            ));

            $info = [$url,$count];
            return $info;
        }
        else { 
            throw new \Exception("You have reached the maximum number of conversions.");
        }
    }
}
?>