<?php
if( ! class_exists( 'WP_List_Table' ) ) {
    require_once( ABSPATH . 'wp-admin/includes/class-wp-list-table.php' );
}

$ssmlp_config = array(
    'pluginurl' => plugins_url()."/SSMLProcessor/",
    'ajaxurl' => admin_url('admin-ajax.php'),
  );
  wp_enqueue_script("ssmlp_script", plugin_dir_url( __FILE__ )."/assets/js/script.js", array( 'jquery' ), true);
  wp_enqueue_style("ssmlp_fontawesome", "https://stackpath.bootstrapcdn.com/font-awesome/4.7.0/css/font-awesome.min.css");
  wp_enqueue_style("ssmlp_css", plugin_dir_url( __FILE__ )."../assets/css/style.css");
  wp_localize_script('ssmlp_script', 'ssmlp', $ssmlp_config);

class SSML_List_Table extends WP_List_Table {

    public function prepare_items(){

    $order_by = isset( $_GET['orderby']) ? trim($_GET['orderby']) : '';
    $order = isset( $_GET['order']) ? trim($_GET['order']) : '';
    $search = isset( $_POST['s']) ? trim($_POST['s']) : ''; 
    $datas = $this->wlt_data($order_by,$order,$search);
  
    $per_page = 20;
    $current_page = $this->get_pagenum();
    $total_items = count($datas);
    $this->set_pagination_args(array(
      'total_items' => $total_items,
      'per_page' => $per_page,
    //   'total_pages' => ceil($total_items / $per_page)
    ));

    $this->items = array_slice($datas,(($current_page -1) * $per_page), $per_page);

    $wlt_columns = $this->get_columns();
    $wlt_hidden = $this->get_hidden_columns();
    $wlt_sortable = $this->get_sortable_columns();
    $this->_column_headers = [ $wlt_columns, $wlt_hidden ,$wlt_sortable];
    }

    public function wlt_data($order_by = '', $order = '', $search = ''){

      ?><section> 
        <h1><?php _e('Audio Database','wlt_text_domain') ?>
        <a class="add_homograph" href="?page=<?=$_GET['page']?>&action=add_new_homograph">Add New</a>
      </h1>
        
        <?php

      $data_array = [];

      global $wpdb;

      if(!empty($search)) {
        $result = $wpdb->get_results("SELECT * FROM wp_phoneme_ipa WHERE `phrase` LIKE '%$search%' OR `ipa_value` LIKE '%$search%' OR `ipa_audio` LIKE '%$search%'");
      }

      else {

        if($order_by == 'wlt_word' && $order=='asc') {
            $result = $wpdb->get_results("SELECT * FROM wp_phoneme_ipa WHERE `id` != 'null' ORDER BY phrase asc");
          }

          else if($order_by == 'wlt_word' && $order=='desc') {
            $result = $wpdb->get_results("SELECT * FROM wp_phoneme_ipa WHERE `id` != 'null' ORDER BY phrase desc");
          }

          else {
            $result = $wpdb->get_results("SELECT * FROM wp_phoneme_ipa WHERE `id` != 'null' ORDER BY phrase asc");
          }
      }

      $rowcount = $wpdb->num_rows;

      $author_id = get_post_field( 'post_author', $post_id );
			$author_name = get_the_author_meta( 'display_name', $author_id );

      if($rowcount>0){
        foreach($result as $row){
            $data_array[] = [
            'wlt_id' => $row->id,
            'wlt_word' => $row->phrase,
            'wlt_ipa_spell' => $row->ipa_value,
            'wlt_audio' => $row->ipa_audio,
            ];
        }
    }
    else {
        echo "<tr><td cols=an='5'>No records found</td></tr>";
    }
      ?></section><?php
      return $data_array;
    }

    public function get_hidden_columns(){
        // return[];
        return ['wlt_id'];
    }

    public function get_sortable_columns(){
        return [
            'wlt_word'=>['wlt_word',true],
        ];
    }

    // public function get_bulk_actions(){
    //     $actions = [
    //         'delete' => 'Delete',
    //         'edit' => 'Edit'
    //     ];
    //     return $actions;
    // }

    public function get_columns(){
      $columns = [
        // 'cb' => '<input type="checkbox"/>',
        'wlt_id' => 'ID',
        'wlt_word' => 'Word',
        'wlt_ipa_spell' => 'IPA Spelling(s)',
        'wlt_audio' => 'Audio Output',
        'action' => 'Action'
      ];
      return $columns;
    }

    public function column_default($item,$column_name){
      switch($column_name){
        case 'wlt_id':
        case 'wlt_word':
        case 'wlt_ipa_spell':
        case 'wlt_audio':
          return $item[$column_name];
          case 'action' :
            $play_audio = '<a class="play-audio" data-url="'.$item['wlt_audio'].'" title="Play"><i class="fa fa-volume-up homograph_edit"></i></a> | ';
            $edit = '<a href="?page='.$_GET['page'].'&action=wlt_edit&id='.$item['wlt_id'].'"><i class="fa fa-edit homograph_edit" title="Edit"></i></a> | ';
            $delete = "<a href=\"?page=".$_GET['page']."&action=wlt_delete&id=". $item['wlt_id'] ."\" onClick=\" return confirm('Are you sure you want to delete this item?') \"><i class=\"fa fa-trash homograph_edit\" style=\"color:red;\" title=\"Delete\"></i></a>";
            $download = '| <a href="'.$item['wlt_audio'].'"id="d" title="Download"><i class="fa fa-download homograph_edit"></i></a>';
            return $play_audio.$edit.$delete.$download;
          default:
              return 'No Value';
      }
      
    }

    public function column_wlt_word($item){
        
        $action = [
            'edit' => "<a href='?page=".$_GET['page']."&action=wlt_edit&id=".$item['wlt_id']."'>Edit</a>",
            'delete' => "<a href='?page=".$_GET['page']."&action=wlt_delete&id=".$item['wlt_id']."' onclick=\"return confirm('Are you sure you want to delete this item?')\">Delete</a>",
        ];

        return sprintf('%1$s %2$s', $item['wlt_word'], $this->row_actions($action));
      }

    // public function column_cb($items){
    //   $checkbox = '<input type="checkbox" />';
    //   return $checkbox;

    // }
}
   function wlt_layout(){
  $wlt_table = new SSML_List_Table();
  $wlt_table->prepare_items();
  echo '<form method="post" name="frm_search_post" action="'.$_SERVER['PHP_SELF'].'?page=homograph_data">';
  $wlt_table->search_box('Search', 'search_post_id');
  echo '</form>';
  $wlt_table->display();
}
  wlt_layout();  
  ?>
  <script>
      jQuery(document).on("click",".play-audio", function() {
        const audio_url = jQuery(this).data('url')
        if(audio_url) {
          const audio = new Audio(audio_url)
          audio.play()
        }
        else {
          alert('No audio available for this word, please add the audio from the editor first!')
          return
        }
      })
  </script>